defmodule ChronoscopeWeb.Router do
  use ChronoscopeWeb, :router

  pipeline :browser do
    plug :accepts, ["html"]
    plug :fetch_session
    plug :fetch_live_flash
    plug :put_root_layout, html: {ChronoscopeWeb.Layouts, :root}
    plug :protect_from_forgery
    plug :put_secure_browser_headers
  end

  pipeline :api do
    plug :accepts, ["json"]
  end

  scope "/", ChronoscopeWeb do
    pipe_through :browser

    get "/", PageController, :home
  end

  scope "/api/v1", ChronoscopeWeb.API.V1 do
    pipe_through :api

    get "/health", HealthController, :get
  end

  scope "/api/v1/nts", ChronoscopeWeb.API.V1.NTS do
    pipe_through :api

    get "/key-establishment", KeyEstablishmentController, :get
  end

  scope "/api/v1/gemini", ChronoscopeWeb.API.V1.Gemini do
    pipe_through :api

    get "/connect", ConnectionController, :get
  end

  # Enable LiveDashboard and Swoosh mailbox preview in development
  if Application.compile_env(:chronoscope, :dev_routes) do
    # If you want to use the LiveDashboard in production, you should put
    # it behind authentication and allow only admins to access it.
    # If your application does not have an admins-only section yet,
    # you can use Plug.BasicAuth to set up some basic authentication
    # as long as you are also using SSL (which you should anyway).
    import Phoenix.LiveDashboard.Router

    scope "/dev" do
      pipe_through :browser

      live_dashboard "/dashboard", metrics: ChronoscopeWeb.Telemetry
      forward "/mailbox", Plug.Swoosh.MailboxPreview
    end
  end
end
